/*
 * Hornsey - Moblin Media Player.
 * Copyright © 2009 Intel Corporation.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef __HRN_DRAG_N_DROP_H__
#define __HRN_DRAG_N_DROP_H__

#define HRN_DROP_MASK_QUEUE    (1<<0)
#define HRN_DROP_MASK_SIDEBAR  (1<<1)

void hrn_actor_make_draggable (ClutterActor *actor,
                               ClutterActor *drag_pad,
                               guint         mask,
                               GCallback     start_drag_cb,
                               GCallback     can_drop_cb,
                               GCallback     drop_cb,
                               gpointer      data);

#endif
